MODULE constants
  INTEGER,  PARAMETER :: dp = KIND(1.0D0)
  INTEGER, PARAMETER :: dpc = KIND((1.0D0,1.0D0))
  ! min and max isospin projection
  INTEGER, PUBLIC :: itzmin, itzmax
  ! min and max total two-body angular momentum in lab frame
  INTEGER, PUBLIC :: j_lab_min, j_lab_max
  ! min and max total two-body angular momentum in Rel-CoM frame
  INTEGER, PUBLIC :: jmin, jmax
  ! max value of 2n+l = nlmax in rel and CoM frame. lmax is max relative l
  INTEGER, PUBLIC :: nlmax, lmax, nmax, nlmax_model, lab_lmax, lab_nmax
  ! number of integration points in relative and CoM momenta
  INTEGER , PUBLIC :: n_rel, n_cm_mom
  ! define the rank of the one-body operator, e.g., M1 --> lambda = 1, GT
  ! lambda = 1, E2 lambda=2 and so forth.
  INTEGER, PUBLIC :: lambda
  ! number of starting energies used to compute the g-matrix
  INTEGER, PUBLIC :: n_startenergy_g
  ! number of starting energies used to compute the Q-box, typically 11
  ! can then compute up to the tenth derivative of the Q-box
  INTEGER, PUBLIC :: n_startenergy_veff
  ! number of excitations (using harmonic oscillator picture) for diagrams
  INTEGER, PUBLIC :: number_homega_exct
  ! A of closed shell core
  INTEGER, PUBLIC :: mass_nucleus
  ! Number of BHF iterations needed for self-consistency 
  INTEGER, PUBLIC :: hf_iterations
  ! define whether onebody, twobody or threebody interaction
  CHARACTER (LEN=100), PUBLIC :: n_body_int
  ! if you want a one-body operator, define it here. Options are
  ! none, gamow-teller, electro, magnetic
  CHARACTER (LEN=100), PUBLIC :: type_of_operator, order_of_interaction
  LOGICAL, PUBLIC :: square_calculation, bhf_calculation
  !    determine the type of Pauli operator
  CHARACTER (LEN=100), PUBLIC :: pauli_operator
  !    determine if you want to have an A-dependent correction to vlowk and G
  CHARACTER (LEN=100), PUBLIC :: adependency
  !    the factor is either 1 or (1-1/A)  if adependecy = yes
  REAL(DP), PUBLIC :: a_factor,dnu
  !    type of effective interaction : coupled-cluster
  !    gmatrix, core-energy
  !    folded-diagrams
  CHARACTER (LEN=100), PUBLIC :: type_of_interaction, type_of_renormv
  ! the nn potential, cd-bonn, idaho-a, idaho-b etc
  CHARACTER (LEN=100), PUBLIC  :: type_of_pot
  ! decide whether you wish to keep the original energies in HF calculations or not
  CHARACTER (LEN=100), PUBLIC  :: keep_originalenergies
  ! folded diagrams
  CHARACTER (LEN=100), PUBLIC  :: folded_diagrams
  ! arrays of starting energies
  REAL(DP), PUBLIC, ALLOCATABLE :: wcn(:), e_start_g(:)
  ! which starting energy is used to compute the effective interaction
  REAL(DP), PUBLIC :: starting_energy
  ! oscillator energy and oscillator length
  REAL(DP), PUBLIC :: hbar_omega, oscl, cutoff
  REAL(DP) , PARAMETER, PUBLIC :: p_mass =   938.918725_dp  !   2006 value of average (m_p+m_n)/2
  REAL(DP), PARAMETER, PUBLIC :: theta_rot = 0.0_dp! 0.125_dp
  REAL(DP), PARAMETER, PUBLIC :: hbarc = 197.326968_dp      !   2006 PDG values
  REAL(DP), PARAMETER, PUBLIC :: hb2ip = hbarc*hbarc/p_mass
  REAL(DP), PUBLIC, PARAMETER :: pi = 3.141592741012573_dp
  REAL(DP), PUBLIC, PARAMETER :: pi_2 = 1.570796370506287_dp
  REAL(DP), PUBLIC, PARAMETER :: pi_4 = 0.7853981852531433_dp
  integer::ifnocore,core,below_ef,tot_orbs,hamiltonian_type,neutron_system,tz_min,tz_max,tz_cc_min,tz_cc_max
  real(8)::final_s,com_beta,com_kin_beta,com_switch,z2_factor,z_factor
END MODULE constants

